<?php
/**
 * Plugin Name: WP Auto Redirect
 * Plugin URI: https://teesharp.com/wp-auto-redirect
 * Description: Automatically redirect users after login based on their role. Useful for membership sites and multi-user platforms.
 * Version: 1.0.0
 * Author: Zumba Apps
 * Author URI: https://teesharp.com
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: wp-auto-redirect
 * Domain Path: /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

class WP_Auto_Redirect
{

    /**
     * Initialize the plugin
     */
    public function __construct()
    {
        // Add login redirect filter
        add_filter('login_redirect', array($this, 'redirect_user_after_login'), 10, 3);

        // Add admin menu
        add_action('admin_menu', array($this, 'add_admin_menu'));

        // Register settings
        add_action('admin_init', array($this, 'register_settings'));
    }

    /**
     * Redirect users after login based on their role
     *
     * @param string $redirect_to URL to redirect to
     * @param string $request URL the user is coming from
     * @param object $user Logged user's data
     * @return string
     */
    public function redirect_user_after_login($redirect_to, $request, $user)
    {
        // If there's no user or there's an error, return the default
        if (!is_object($user) || is_wp_error($user)) {
            return $redirect_to;
        }

        // Get redirect URLs for each role
        $redirect_urls = get_option('wp_auto_redirect_urls', array());

        // Find the highest priority role that has a redirect URL
        if (!empty($user->roles) && is_array($user->roles)) {
            foreach ($user->roles as $role) {
                if (isset($redirect_urls[$role]) && !empty($redirect_urls[$role])) {
                    return $redirect_urls[$role];
                }
            }
        }

        // Return default redirect if no role-specific URL is set
        return $redirect_to;
    }

    /**
     * Add plugin menu under Settings
     */
    public function add_admin_menu()
    {
        add_options_page(
            'WP Auto Redirect Settings',
            'Auto Redirect',
            'manage_options',
            'wp-auto-redirect',
            array($this, 'display_settings_page')
        );
    }

    /**
     * Register plugin settings
     */
    public function register_settings()
    {
        register_setting(
            'wp_auto_redirect_settings',
            'wp_auto_redirect_urls',
            array($this, 'sanitize_urls')
        );
    }

    /**
     * Sanitize URLs before saving
     *
     * @param array $input The unsanitized URLs
     * @return array The sanitized URLs
     */
    public function sanitize_urls($input)
    {
        $sanitized_input = array();

        if (is_array($input)) {
            foreach ($input as $role => $url) {
                if (!empty($url)) {
                    $sanitized_input[$role] = esc_url_raw($url);
                }
            }
        }

        return $sanitized_input;
    }

    /**
     * Display the settings page
     */
    public function display_settings_page()
    {
        // Get all roles
        $roles = wp_roles()->get_names();

        // Get saved redirect URLs
        $redirect_urls = get_option('wp_auto_redirect_urls', array());
        ?>
        <div class="wrap">
            <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
            <p><?php _e('Configure redirect URLs for each user role. When a user logs in, they will be redirected to the URL specified for their role. If a user has multiple roles, the first role with a redirect URL will be used.', 'wp-auto-redirect'); ?>
            </p>

            <form method="post" action="options.php">
                <?php settings_fields('wp_auto_redirect_settings'); ?>
                <?php do_settings_sections('wp_auto_redirect_settings'); ?>

                <table class="form-table">
                    <tbody>
                        <?php foreach ($roles as $role_id => $role_name): ?>
                            <tr>
                                <th scope="row">
                                    <label for="wp_auto_redirect_urls_<?php echo esc_attr($role_id); ?>">
                                        <?php echo esc_html($role_name); ?>
                                    </label>
                                </th>
                                <td>
                                    <input type="url" id="wp_auto_redirect_urls_<?php echo esc_attr($role_id); ?>"
                                        name="wp_auto_redirect_urls[<?php echo esc_attr($role_id); ?>]"
                                        value="<?php echo isset($redirect_urls[$role_id]) ? esc_url($redirect_urls[$role_id]) : ''; ?>"
                                        class="regular-text">
                                    <p class="description">
                                        <?php printf(__('Enter the URL where %s should be redirected after login.', 'wp-auto-redirect'), esc_html($role_name)); ?>
                                    </p>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>

                <?php submit_button(); ?>
            </form>
        </div>
        <?php
    }
}

// Initialize the plugin
$wp_auto_redirect = new WP_Auto_Redirect();